traitsui\.ui\_editors\.data\_frame\_editor module
=================================================

.. automodule:: traitsui.ui_editors.data_frame_editor
    :members:
    :undoc-members:
    :show-inheritance:
